/*
 * Application.java
 *
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
 */

package eu.europa.echa.reach.preregistration.examples.oobase;

import eu.europa.echa.reach.preregistration.PreRegistration;
import java.io.FileInputStream;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.Statement;
import java.util.Properties;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;

/**
 *
 * @author Csk Gbor
 */
public class Application {
    
    private static final Logger logger = Logger.getLogger(Application.class);
    
    public Application() {
    }
    
    public static void main(String[] args) {
        
        //configure default log4j logging
        BasicConfigurator.configure();
        Logger.getRootLogger().setLevel(Level.INFO);
        
        logger.debug("Application Start");
        
        try {
            Properties properties = new Properties();
            {
                InputStream inputStream = ClassLoader.getSystemResourceAsStream("oobase.properties");
                if (inputStream == null) {
                    logger.error("Properties cannot be loaded");
                    throw new NullPointerException("Properties cannot be loaded");
                } else {
                    properties.load(inputStream);
                }
            }
            String ooBaseFileName;
            if (args.length > 0) {
                ooBaseFileName = args[0];
            } else {
                ooBaseFileName = properties.getProperty("openoffice.base.filename", "preregistration.odb");
            }
            logger.debug("Opening database: " + ooBaseFileName);
            InputStream inputStream = new FileInputStream(ooBaseFileName);
            logger.info("Using database: " + ooBaseFileName);
            Connection connection = OdbFile.getConnection(inputStream);
            try {
                PreRegistration preRegistration = new PreRegistration(properties);
                preRegistration.loadSubstanceIdentities(connection);
                preRegistration.serialize(properties.getProperty("output.file", "preregistration"));
            } finally {
                if (connection != null) {
                    try {
                        logger.debug("Closing db connection");
                        // shut the db down
                        Statement stmnt = connection.createStatement();
                        stmnt.execute("SHUTDOWN");
                    } catch (Exception ex) {
                        logger.error("SHUTDOWN of HSQLDB failed", ex);
                    }
                    connection.close();
                    connection = null;
                    logger.debug("Db connection closed");
                }
            }
        } catch (Exception ex) {
            logger.error("Uncaught Exception: ", ex);
        }
        logger.debug("Application Exit");
    }
    
}
