/*
 * OdbFile.java
 *
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
 */

package eu.europa.echa.reach.preregistration.examples.oobase;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.sql.Connection;
import java.sql.Driver;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import org.apache.log4j.Logger;

/**
 *
 * @author Csk Gbor
 */
public class OdbFile {
    
    private static final Logger logger = Logger.getLogger(OdbFile.class);
    
    private OdbFile() {
    }
    
    public static Connection getConnection(final InputStream inputStream)
    throws IOException, ClassNotFoundException, InstantiationException, IllegalAccessException, SQLException {
        if (inputStream == null) {
            throw new IllegalArgumentException("inputStream");
        }
        // Get name for temporary database
        String dbPath;
        {
            File tmpFile = File.createTempFile("oodb","");
            dbPath = tmpFile.getAbsolutePath().replaceAll("\\\\","/");
            tmpFile.delete();
        }
        logger.debug("Temporary hsql database: " + dbPath);
        ZipInputStream zip = new ZipInputStream(inputStream);
        ZipEntry zipEntry;
        byte[] buffer = new byte[1024];
        while((zipEntry = zip.getNextEntry()) != null) {
            if (zipEntry.getName().startsWith("database/")) {
                File outFile = new File(dbPath + "." + zipEntry.getName().substring(9));
                outFile.deleteOnExit();
                logger.info("Extracting: " + zipEntry.getName() + " -> " + outFile.getAbsolutePath());
                OutputStream outStream = new FileOutputStream(outFile);
                int length;
                while((length = zip.read(buffer)) > 0) {
                    outStream.write(buffer, 0, length);
                }
                outStream.flush();
                outStream.close();
            } else {
                logger.debug("Not extracting: " + zipEntry.getName());
            }
        }
        
        Connection connection = null;
        final String DRIVER_CLASS = "org.hsqldb.jdbcDriver";
        logger.debug("Loading driver: " + DRIVER_CLASS);
        Driver driver = (Driver) Class.forName(DRIVER_CLASS).newInstance();
        DriverManager.registerDriver(driver);
        final String dbUrl = "jdbc:hsqldb:file:" + dbPath.replace('\\','/');
        logger.debug("Connecting to database: " + dbUrl);
        connection = DriverManager.getConnection(dbUrl, "sa", "");
        logger.info("Connected to database: " + dbUrl);
        return connection;
    }
    
}
